%
%            FILE DESCRIBING GMU Monthly South American Precipitation Dataset

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';

% VARIABLES -- OPTIONAL
CatalogServer = ...
    'http://dods.gso.uri.edu/cgi-bin/nph-dods/catalog/sa_precip.dat';
% The inclusion of these fields means that returning user vectors
% Longitude and Latitude will be simulated and not downloaded.
Nlon = 55;
Nlat = 75;
% axes_order indicates the position of these axes: x, y, z, t
% in the URL constraint.  This is because there is NO METADATA
% to help constrain the URL.  In this case, since Nlon and Nlat
% are specified as well, simulated axes (created from the metadata
% herein) will be used to make the constraint.
axes_order = [2 1 0 0];

% VARIABLES -- REQUIRED
LonRange = [275.5 329.5];
LatRange = [14.5 -59.5];
TimeRange = [1960+14/366 1990+340/365];
DepthRange = [0 0];
Resolution = 111.0;
DepthUnits = '';

DataName = 'Precip - South America Monthly Mean - Gridded  - GMU';
SelectableVariables = str2mat('Precipitation');
DodsName = str2mat('precip');
% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
[DataNull(5:length(DataNull))] = deal({-9.99990039062500e3});
DataScale = [0.0 1.0; 0.0 1.0; NaN NaN; NaN NaN; ...
               0.0  1.0];
Data_Use_Policy='';

Acknowledge = sprintf('%s\n\n%s\n\n%s\n\n%s\n%s\n%s\n%s\n%s', ...
         [ 'The authors of this dataset are ', ...
	   ' Scott R. Webber and Cort J. Willmott .'], ...
	 'The data are provided by  Ruixin Yang', ...
	 [ 'and accessed by the Distributed Oceanographic Data ', ...
	   'System (DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
	 'Citation: ', ...
	 [ ' Shepard, D. (1968)  A two-dimensional Interpolation function for', ...
	   ' irregularly-spaced Data.  Proceedings, 1968 ACM National', ...
	   ' Conference, 517-523.'], ...
	 [ ' Webber, S. R. and C. J. Willmott (1998) South American', ...
	   ' Precipitation: Station Records Archive.  (in preparation)'], ...
	 [ ' Willmott, C. J. and S. M. Robeson (1995) Climatologically Aided', ...
	   ' Interpolation (CAI) of Terrestrial Air Temperature. ', ...
	   ' International Journal of Climatology, 15, 221-229.'], ...
	 [ ' Willmott, C. J., C. M. Rowe and W. D. Philpot (1985)  ', ...
	   ' Small-Scale Climate Maps:  A Sensitivity Analysis of Some', ...
	   ' Common Assumptions Associated with Grid-point Interpolation', ...
	   ' and Contouring.  American Cartographer, 12, 5-16.', ...
	   ' ']);

%COMMENTS
Comments1 = sprintf('%s\n', ...
' WARNING WARNING WARNING WARNING', ...
'    The DODS Distribution of this Dataset is still under development.', ...
'    For more information contact Paul Hemenway, ', ...
'    University of Rhode Island', ...
'    paul@koko.gso.uri.edu', ...
' ', ...
'           South America Gridded Monthly Precipitation', ...
' 1960-1990 Gridded Monthly Time Series', ...
' Scott R. Webber and Cort J. Willmott', ...
' (with support from NASA''s Seasonal and Interannual ESIP)', ...
' For additional information concerning this archive,', ...
' please contact us at:', ...
' Center for Climatic Research', ...
' ', ...
'                   Department of Geography', ...
'                    University of Delaware', ...
'                       Newark, DE 19716', ...
'                        (302) 831-2294', ...
'                               ', ...
'                              or', ...
'                               ', ...
'                       webber@udel.edu', ...
' ', ...
' ', ...
' Achive (Version 1.02) created October 27, 1998', ...
' ===============================================================', ...
' ', ...
' ', ...
' ', ...
' STATION DATA SOURCE:', ...
' ', ...
'      Monthly-total precipitation (P) for 4,505 stations from', ...
'      Webber and Willmott''s (1998) "South American Precipitation: ', ...
'      Station Records Archive (version 1.02)" were used to produce', ...
'      this archive.  Work on Webber and Willmott''s (1998) station-', ...
'      record data set is ongoing, and it is unavailable for', ...
'      distribution at this time.', ...
' ', ...
' ', ...
' ', ...
' SPATIAL INTERPOLATION:', ...
' ', ...
'      Traditional interpolation was accomplished with the', ...
'      spherical version of Shepard''s algorithm, which employs an', ...
'      enhanced distance-weighting method (Shepard, 1968; Willmott', ...
'      et al., 1985).  Station precipitation values were', ...
'      interpolated to a 1 degree by 1 degree of', ...
'      latitude/longitude grid, where the grid nodes are centered');

Comments2 = sprintf('%s\n', ...
'      on the degree.  The number of nearby stations that', ...
'      influence a grid-node estimate was increased to an average', ...
'      of 20, from an average of 7 in earlier applications.  This', ...
'      resulted in smaller cross-validation errors (see below) and', ...
'      visually more realistic precipitation fields.  A more robust', ...
'      neighbor finding algorithm, based on spherical distance,', ...
'      also was developed and used.', ...
' ', ...
'      Incorporating a climatology, from a relatively-dense network', ...
'      of stations, can further increase the accuracy of spatially', ...
'      interpolating time series of monthly climate variables', ...
'      (Willmott and Robeson, 1995).  Climatologically-aided', ...
'      interpolation (CAI) of monthly precipitation, therefore, was', ...
'      employed.  Briefly, monthly precipitation at each station', ...
'      (from the time series) is first differenced from monthly', ...
'      climatological averages available at or interpolated to the', ...
'      station locations.  Traditional interpolation then is', ...
'      performed on the station differences to obtain a gridded', ...
'      difference field.  Finally, the gridded difference field is', ...
'      added to traditionally interpolated estimates of climatology', ...
'      at the same grid points.', ...
' ', ...
' ', ...
' ', ...
' SPATIAL CROSS VALIDATION:', ...
' ', ...
'      To indicate (roughly) the spatial interpolation errors,', ...
'      station-by-station cross validation was employed (Willmott', ...
'      and Matsuura, 1995).  One station is removed at a time, and', ...
'      precipitation is then interpolated to the removed station', ...
'      location from the surrounding nearby stations.  The', ...
'      difference between the real station value and the', ...
'      interpolated value is a local estimate of interpolation', ...
'      error.  After each station cross validation is made, the', ...
'      removed station is put back into the network.  To reduce', ...
'      network biases on cross-validation results, absolute values', ...
'      of the errors at the stations were interpolated to the same', ...
'      spatial resolution as the precipitation field.', ...
' ', ...
' SELECTED REFERENCES:', ...
' ', ...
' Shepard, D. (1968)  A two-dimensional Interpolation function for', ...
'      irregularly-spaced Data.  Proceedings, 1968 ACM National', ...
'      Conference, 517-523.', ...
' ', ...
' Webber, S. R. and C. J. Willmott (1998) South American', ...
'      Precipitation: Station Records Archive.  (in preparation)');

Comments3 = sprintf('%s\n', ...
' ', ...
' Willmott, C. J. and S. M. Robeson (1995) Climatologically Aided', ...
'      Interpolation (CAI) of Terrestrial Air Temperature. ', ...
'      International Journal of Climatology, 15, 221-229.', ...
' ', ...
' Willmott, C. J., C. M. Rowe and W. D. Philpot (1985)  ', ...
'      Small-Scale Climate Maps:  A Sensitivity Analysis of Some', ...
'      Common Assumptions Associated with Grid-point Interpolation', ...
'      and Contouring.  American Cartographer, 12, 5-16.', ...
' ');

Comments4 = sprintf('%s\n', ...
'    ', ...
'    Units:   (mm) ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Month:1960/1 ', ...
'         Ending_Month:1990/12 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:275.5 ', ...
'              East Bounding Coordinate:329.5 ', ...
'              South Bounding Coordinate:-59.5 ', ...
'              North Bounding Coordinate:+14.5 ', ...
'    Point_of_Contact (Science) = ', ...
'            contact-name: ', ...
'            contact-address1: ', ...
'            contact-address2: ', ...
'               contact-address3: ', ...
'               contact-country: ', ...
'        contact-Telephone: (xxx) xxx-xxxx', ...
'       contact-Electronic Mail Address:INTERNET  > xxx@xxx.xxx.xxx ', ...
'       contact-http: ', ...
'    ', ...
'    Point_of_Contact (Data Provision) = ', ...
'               name: Ruxin Yang', ...
'               address1: George Mason University', ...
'               address2: ', ...
'               country: USA', ...
'               Telephone: (xxx) xxx-xxxx', ...
'         Electronic Mail Address:INTERNET > yang@science.gmu.edu');

Comments = [Comments1 Comments2 Comments3 Comments4];

% The preceeding blank line is important for cvs.
% $Id: gmup1.m,v 1.7 2002/01/29 18:22:02 dbyrne Exp $
%

% $Log: gmup1.m,v $
% Revision 1.7  2002/01/29 18:22:02  dbyrne
% *** empty log message ***
%
% Revision 1.6  2002/01/28 20:43:06  dbyrne
% *** empty log message ***
%
% Revision 1.5  2002/01/23 18:13:40  dbyrne
% *** empty log message ***
%
% Revision 1.4  2002/01/22 21:23:23  dan
% Modified CatalogServer entry for current usage.
%
% Revision 1.3  2001/01/18 19:35:44  dbyrne
%
%
% datarange is no longer in use.  changed datanull to cell in many cases.
% -- dbyrne 01/01/17
%
% Revision 1.2  2000/06/16 02:51:53  dbyrne
%
%
% Upgrades for standardization/toolbox. -- dbyrne 00/06/15
%
% Revision 1.2  2000/06/15 22:46:43  root
% *** empty log message ***
%
% Revision 1.1  2000/05/31 22:59:20  root
% *** empty log message ***
%
% Revision 1.3  2000/05/24 21:55:31  root
% Fixed use of getrectf, since the dataset has a cat. server.  dbyrne 00/05/25
%
% Revision 1.2  2000/03/28 20:23:45  root
% Updates from release gui-3-2-0
%
% Revision 1.5  2000/03/16 04:01:06  dbyrne
%
%
% Changed max datarange to 1.0e3, to be closer to max in dataset
% of 863mm.  -- dbyrne 00/03/14
%
% Revision 1.4  1999/07/21 15:35:54  dbyrne
%
%
% Corrected language in Acknowledgements.  --dbyrne 99/07/21
%
% Revision 1.3  1999/06/01 00:53:51  dbyrne
%
%
% Many fixes in prep for AGU.  fth, htn, glk and prevu changed to use
% fileservers. -- dbyrne 99/05/31
%
% Revision 1.2  1999/05/21 17:46:23  paul
%  add DepthUnits = '';  .....  phemenway
%
% Revision 1.1  1999/05/21 16:54:40  paul
% Initial version...phemenway
%
